pub enum EntityAccessErr {
UseAfterFree,
NullReference,
}Expand description
Possible errors when accessing allocated entities.
分配实体访问时可能出现的错误.
Variants
UseAfterFree
The entity has been freed and cannot be accessed.
实体已被释放,无法访问。
NullReference
The pointer is null and does not reference any entity.
指针为空,未引用任何实体。