OrderRepr

Enum OrderRepr 

pub enum OrderRepr {
    Exact,
    Relative,
}
Representation of order cache in an order-cached list. This will determine when the order cache is invalidated.

Variants



Exact

The order exactly represents the position in the list. e.g.

List: (Head = 0) <-> A(1) <-> B(2) <-> C(3) <-> (Tail = usize::MAX)

Invalidates the order cache on any insertion or removal except when inserting at the end or removing the last element.



Relative

The order represents a relative position in the list, but not necessarily the exact index. e.g.

List: (Head = 0) <-> A(1) <-> B(3) <-> C(4) <-> (Tail = usize::MAX)