EntityListRange

Struct EntityListRange 

pub struct EntityListRange<I: IEntityListNodeID> {
    pub start: I,
    pub end: Option<I>,
}
A partial-close range of an entity pointer list representing [start, end).

  • if end is None, the range is open-ended.
  • the start is non-nullable, meaning any range must have a valid start.

Fields

start: I

Start ID (inclusive).

end: Option<I>

Optional end ID (exclusive). If None, the range is open-ended.

Implementations

Source

impl<I: IEntityListNodeID> EntityListRange<I>

pub fn is_empty(&self) -> bool

Check if the range is empty.

pub fn iter<'a>(&self, alloc: &'a IDBoundAlloc<I>) -> EntityListIter<'a, I>

Create an iterator over this range.