pub struct EntityListRange<I: IEntityListNodeID> {
pub start: I,
pub end: Option<I>,
}Expand description
A partial-close range of an entity pointer list representing [start, end).
- if
end is None, the range is open-ended. - the
startis non-nullable, meaning any range must have a valid start.
Fields
start: Iend: Option<I>Implementations
Sourceimpl<I: IEntityListNodeID> EntityListRange<I>
impl<I: IEntityListNodeID> EntityListRange<I>