EntityListRange

Struct EntityListRange 

pub struct EntityListRange<E: IEntityListNode> {
    pub start: E::PtrID,
    pub end: Option<E::PtrID>,
}
A partial-close range of an entity pointer list representing [start, end).

  • if end is None, the range is open-ended.
  • the start is non-nullable, meaning any range must have a valid start.

Fields

start: E::PtrIDend: Option<E::PtrID>

Implementations

Source

impl<E: IEntityListNode> EntityListRange<E>

pub fn is_empty(&self) -> bool

pub fn iter<'alloc>( &self, alloc: &'alloc EntityAlloc<E>, ) -> EntityListReadIter<'alloc, E>