pub struct EntityListRange<E: IEntityListNode> {
pub start: E::PtrID,
pub end: Option<E::PtrID>,
}Expand description
A partial-close range of an entity pointer list representing [start, end).
- if
end is None, the range is open-ended. - the
startis non-nullable, meaning any range must have a valid start.
Fields
start: E::PtrIDend: Option<E::PtrID>Implementations
Sourceimpl<E: IEntityListNode> EntityListRange<E>
impl<E: IEntityListNode> EntityListRange<E>
pub fn is_empty(&self) -> bool
pub fn iter<'alloc>( &self, alloc: &'alloc EntityAlloc<E>, ) -> EntityListReadIter<'alloc, E> ⓘ