pub struct PtrID<E: IEntityAllocatable>(/* private fields */);Implementations
Sourceimpl<E: IEntityRingListNode> PtrID<E>
impl<E: IEntityRingListNode> PtrID<E>
pub fn detach(self, alloc: &EntityAlloc<E>) -> PtrListRes<E>
Sourceimpl<E: IEntityAllocatable> PtrID<E>
impl<E: IEntityAllocatable> PtrID<E>
pub unsafe fn direct_get_indexed(self) -> usize
pub unsafe fn direct_deref<'a>(self) -> &'a E
pub unsafe fn direct_deref_mut<'a>(self) -> &'a mut E
pub fn as_indexed(self, alloc: &EntityAlloc<E>) -> Option<IndexedID<E>>
Sourcepub fn as_unit_pointer(self) -> *const Unit<E>
pub fn as_unit_pointer(self) -> *const Unit<E>
Get a raw pointer to the Unit
Returning a raw pointer is safe; dereferencing it remains unsafe and the caller must ensure the pointed unit is still allocated and valid.